pub(crate) enum ScreenshotRequestState {
Pending,
WaitingOnScript,
}Expand description
When a ScreenshotReadinessRequest is received from the renderer, the
crate::Constellation goes through a variety of states to process them. This data structure
represents those states.
Variants
Pending
The crate::Constellation has received the ScreenshotReadinessRequest, but has not
yet forwarded it to the Pipeline’s of the request’s WebView. This is likely because there
are still pending navigation changes in the crate::Constellation. Once those changes are
resolved the request will be forwarded to the Pipelines.
WaitingOnScript
The crate::Constellation has forwarded the ScreenshotReadinessRequest to the
Pipelines of the corresponding WebView. The Pipelines are waiting for a variety of
things to happen in order to report what the appropriate display list epoch is for the
screenshot. Once they all report back, the crate::Constellation considers that the
request is handled, and the renderer is responsible for waiting to take the screenshot.